netapp_ontap.models.byte_lock API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.byte_lock`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ByteLockSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ByteLock object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `exclusive: bool GET`

    Indicates whether it is an exclusive bytelock.

  `length: Size GET`

    Length of the bytelock starting from the offset.

    Example: 10

  `mandatory: bool GET`

    Indicates whether or not the bytelock is mandatory.

  `offset: Size GET`

    Starting offset for a bytelock.

    Example: 100

  `soft: bool GET`

    Indicates whether it is a soft bytelock.

  `super: bool GET`

    Indicates whether it is a super bytelock.